/*
 * Sone - PostReply.java - Copyright © 2010–2013 David Roden
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package net.pterodactylus.sone.data;

/**
 * A reply is like a {@link Post} but can never be posted on its own, it always
 * refers to another {@link Post}.
 *
 * @author <a href="mailto:bombe@pterodactylus.net">David ‘Bombe’ Roden</a>
 */
public interface PostReply extends Reply<PostReply> {

	/**
	 * Returns the ID of the post this reply refers to.
	 *
	 * @return The ID of the post this reply refers to
	 */
	public String getPostId();

	/**
	 * Returns the post this reply refers to.
	 *
	 * @return The post this reply refers to
	 */
	public Post getPost();

	/**
	 * Sets the post this reply refers to.
	 *
	 * @param postId
	 *            The ID of the post to reply to
	 * @return This reply
	 */
	public PostReply setPost(String postId);

}
